package com.bonus.sgzb.machine.service;

import com.bonus.sgzb.machine.damain.MaPropInfo;

import java.util.List;

/**
 * 资产管理ma_prop_info(MaPropInfo)表服务接口
 *
 * @author makejava
 * @since 2023-11-28 10:18:10
 */
public interface IMaPropInfoService {

    /**
     * 查询资产属性列表
     * @param propName
     * @return
     */
    List<MaPropInfo> selectMaPropInfoList(String propName);

    /**
     * 校验资产项目名称唯一性
     * @param maPropInfo
     * @return
     */
    boolean checkPropNameUnique(MaPropInfo maPropInfo);

    /**
     * 新增资产项目
     * @param maPropInfo
     * @return
     */
    int insertMaPropInfo(MaPropInfo maPropInfo);

    /**
     * 删除资产管理
     * @param propId
     * @return
     */
    int deleteMaPropById(Long propId);

    /**
     * 修改资产管理
     * @param maPropInfo
     * @return
     */
    int updatetMaProp(MaPropInfo maPropInfo);

    /**
     * 导入资产管理数据
     *
     * @param maPropInfoList 用户数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    String importMaProp(List<MaPropInfo> maPropInfoList, boolean isUpdateSupport, String operName);
}

